pub enum TIP20Error {
Show 21 variants
InsufficientBalance(InsufficientBalance),
InsufficientAllowance(InsufficientAllowance),
SupplyCapExceeded(SupplyCapExceeded),
InvalidSupplyCap(InvalidSupplyCap),
InvalidPayload(InvalidPayload),
PolicyForbids(PolicyForbids),
InvalidRecipient(InvalidRecipient),
ContractPaused(ContractPaused),
InvalidCurrency(InvalidCurrency),
InvalidQuoteToken(InvalidQuoteToken),
InvalidAmount(InvalidAmount),
NoOptedInSupply(NoOptedInSupply),
Unauthorized(Unauthorized),
ProtectedAddress(ProtectedAddress),
InvalidToken(InvalidToken),
Uninitialized(Uninitialized),
InvalidTransferPolicyId(InvalidTransferPolicyId),
PermitExpired(PermitExpired),
InvalidSignature(InvalidSignature),
LogoURITooLong(LogoURITooLong),
InvalidLogoURI(InvalidLogoURI),
}Expand description
Container for all the ITIP20 custom errors.
Variants
InsufficientBalance(InsufficientBalance)
InsufficientAllowance(InsufficientAllowance)
SupplyCapExceeded(SupplyCapExceeded)
InvalidSupplyCap(InvalidSupplyCap)
InvalidPayload(InvalidPayload)
PolicyForbids(PolicyForbids)
InvalidRecipient(InvalidRecipient)
ContractPaused(ContractPaused)
InvalidCurrency(InvalidCurrency)
InvalidQuoteToken(InvalidQuoteToken)
InvalidAmount(InvalidAmount)
NoOptedInSupply(NoOptedInSupply)
ProtectedAddress(ProtectedAddress)
InvalidToken(InvalidToken)
Uninitialized(Uninitialized)
InvalidTransferPolicyId(InvalidTransferPolicyId)
PermitExpired(PermitExpired)
InvalidSignature(InvalidSignature)
LogoURITooLong(LogoURITooLong)
InvalidLogoURI(InvalidLogoURI)
Implementations
Sourceimpl ITIP20Errors
impl ITIP20Errors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl ITIP20Errors
impl ITIP20Errors
Sourcepub fn insufficient_balance(
available: Uint<256, 4>,
required: Uint<256, 4>,
token: Address,
) -> ITIP20Errors
pub fn insufficient_balance( available: Uint<256, 4>, required: Uint<256, 4>, token: Address, ) -> ITIP20Errors
Creates a InsufficientBalance error.
error InsufficientBalance(uint256,uint256,address)Sourcepub fn insufficient_allowance() -> ITIP20Errors
pub fn insufficient_allowance() -> ITIP20Errors
Creates a InsufficientAllowance error.
error InsufficientAllowance()Sourcepub fn supply_cap_exceeded() -> ITIP20Errors
pub fn supply_cap_exceeded() -> ITIP20Errors
Creates a SupplyCapExceeded error.
error SupplyCapExceeded()Sourcepub fn invalid_supply_cap() -> ITIP20Errors
pub fn invalid_supply_cap() -> ITIP20Errors
Creates a InvalidSupplyCap error.
error InvalidSupplyCap()Sourcepub fn invalid_payload() -> ITIP20Errors
pub fn invalid_payload() -> ITIP20Errors
Creates a InvalidPayload error.
error InvalidPayload()Sourcepub fn policy_forbids() -> ITIP20Errors
pub fn policy_forbids() -> ITIP20Errors
Creates a PolicyForbids error.
error PolicyForbids()Sourcepub fn invalid_recipient() -> ITIP20Errors
pub fn invalid_recipient() -> ITIP20Errors
Creates a InvalidRecipient error.
error InvalidRecipient()Sourcepub fn contract_paused() -> ITIP20Errors
pub fn contract_paused() -> ITIP20Errors
Creates a ContractPaused error.
error ContractPaused()Sourcepub fn invalid_currency() -> ITIP20Errors
pub fn invalid_currency() -> ITIP20Errors
Creates a InvalidCurrency error.
error InvalidCurrency()Sourcepub fn invalid_quote_token() -> ITIP20Errors
pub fn invalid_quote_token() -> ITIP20Errors
Creates a InvalidQuoteToken error.
error InvalidQuoteToken()Sourcepub fn invalid_amount() -> ITIP20Errors
pub fn invalid_amount() -> ITIP20Errors
Creates a InvalidAmount error.
error InvalidAmount()Sourcepub fn no_opted_in_supply() -> ITIP20Errors
pub fn no_opted_in_supply() -> ITIP20Errors
Creates a NoOptedInSupply error.
error NoOptedInSupply()Creates a Unauthorized error.
error Unauthorized()Sourcepub fn protected_address() -> ITIP20Errors
pub fn protected_address() -> ITIP20Errors
Creates a ProtectedAddress error.
error ProtectedAddress()Sourcepub fn invalid_token() -> ITIP20Errors
pub fn invalid_token() -> ITIP20Errors
Creates a InvalidToken error.
error InvalidToken()Sourcepub fn uninitialized() -> ITIP20Errors
pub fn uninitialized() -> ITIP20Errors
Creates a Uninitialized error.
error Uninitialized()Sourcepub fn invalid_transfer_policy_id() -> ITIP20Errors
pub fn invalid_transfer_policy_id() -> ITIP20Errors
Creates a InvalidTransferPolicyId error.
error InvalidTransferPolicyId()Sourcepub fn permit_expired() -> ITIP20Errors
pub fn permit_expired() -> ITIP20Errors
Creates a PermitExpired error.
error PermitExpired()Sourcepub fn invalid_signature() -> ITIP20Errors
pub fn invalid_signature() -> ITIP20Errors
Creates a InvalidSignature error.
error InvalidSignature()Sourcepub fn logo_uri_too_long() -> ITIP20Errors
pub fn logo_uri_too_long() -> ITIP20Errors
Creates a LogoURITooLong error.
error LogoURITooLong()Sourcepub fn invalid_logo_uri() -> ITIP20Errors
pub fn invalid_logo_uri() -> ITIP20Errors
Creates a InvalidLogoURI error.
error InvalidLogoURI()Trait Implementations
Sourceimpl Clone for ITIP20Errors
impl Clone for ITIP20Errors
Sourcefn clone(&self) -> ITIP20Errors
fn clone(&self) -> ITIP20Errors
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ITIP20Errors
impl Debug for ITIP20Errors
Sourceimpl<'de> Deserialize<'de> for ITIP20Errors
impl<'de> Deserialize<'de> for ITIP20Errors
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ITIP20Errors, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ITIP20Errors, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl Eq for ITIP20Errors
Sourceimpl PartialEq for ITIP20Errors
impl PartialEq for ITIP20Errors
Sourcefn eq(&self, other: &ITIP20Errors) -> bool
fn eq(&self, other: &ITIP20Errors) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ITIP20Errors
impl Serialize for ITIP20Errors
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Sourceimpl SolInterface for ITIP20Errors
impl SolInterface for ITIP20Errors
Sourceconst MIN_DATA_LENGTH: usize = 0usize
const MIN_DATA_LENGTH: usize = 0usize
Sourcefn valid_selector(selector: [u8; 4]) -> bool
fn valid_selector(selector: [u8; 4]) -> bool
true if the given selector is known to this type.Sourcefn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<ITIP20Errors, Error>
fn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<ITIP20Errors, Error>
self.Sourcefn abi_decode_raw_validate(
selector: [u8; 4],
data: &[u8],
) -> Result<ITIP20Errors, Error>
fn abi_decode_raw_validate( selector: [u8; 4], data: &[u8], ) -> Result<ITIP20Errors, Error>
self, with validation. Read moreSourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
self into the given buffer, without any selectors.fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
self into the given buffer.fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
self.fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
self, with validation. Read moreimpl StructuralPartialEq for ITIP20Errors
Sourceimpl TryFrom<TempoPrecompileError> for ITIP20Errors
impl TryFrom<TempoPrecompileError> for ITIP20Errors
Sourcetype Error = TryIntoError<TempoPrecompileError>
type Error = TryIntoError<TempoPrecompileError>
Sourcefn try_from(
value: TempoPrecompileError,
) -> Result<ITIP20Errors, TryIntoError<TempoPrecompileError>>
fn try_from( value: TempoPrecompileError, ) -> Result<ITIP20Errors, TryIntoError<TempoPrecompileError>>